@@ -2,7 +2,6 @@
 import * as widgets from '@jupyter-widgets/base';
 import $ from 'jquery'
 import _ from 'underscore'
-import * as Backbone from 'backbone'
 
 import { Store } from './Store';
 import { Dispatcher } from 'flux'
@@ -12,6 +11,7 @@ import GoogleMapsLoader from 'google-maps';
 import { GMapsLayerView, GMapsLayerModel } from './GMapsLayer';
 import { defaultAttributes } from './defaults'
 import { latLngToArray } from './services/googleConverters'
+import { newEventBus } from './services/eventBus'
 
 
 class DrawingStore extends Store {
@@ -435,7 +435,7 @@ class PolygonClickHandler {
 
 class DeleteClickHandler {
     constructor(features, onDeleteFeature) {
-        this.eventBus = { ...Backbone.Events };
+        this.eventBus = newEventBus()
         this.onDeleteFeature = onDeleteFeature
         this.currentFeatures = features;
         this._registerFeatureListeners(features)
